<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AppMain</name>
    <message>
        <location filename="../src/common/vlcplayer.cpp" line="87"/>
        <source>Voice Notes</source>
        <translation>Memorecorder</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
        <source>Notebook</source>
        <translation>Notitieboek</translation>
    </message>
    <message>
        <location filename="../src/importolddata/olddbvisistors.cpp" line="139"/>
        <source>Voice</source>
        <translation>Memo</translation>
    </message>
    <message>
        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
</context>
<context>
    <name>FolderListView</name>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="517"/>
        <source>Rename</source>
        <translation type="unfinished">Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="526"/>
        <source>Delete</source>
        <translation type="unfinished">Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
        <source>New Note</source>
        <translation>Nieuwe notitie</translation>
    </message>
</context>
<context>
    <name>InitialInterface</name>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
        <source>After creating a new notepad, you can start recording voice and text</source>
        <translation>Na het maken van een nieuw notitieboek kunt u beginnen met het opnemen van stem en tekst</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Notitieboek maken</translation>
    </message>
</context>
<context>
    <name>ItemListView</name>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source>move </source>
        <translation>verplaats </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source> notes to :</source>
        <translation> notities naar :</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
        <source> note to :</source>
        <translation> notitie naar :</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
        <source>Save As</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
        <source>No search results</source>
        <translation type="unfinished">Geen zoekresultaten</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Unpin</source>
        <translation>Ontgrendel</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Sticky on Top</source>
        <translation type="unfinished">Vastzetten aan bovenkant</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
        <source>Sticky Notes</source>
        <translation type="unfinished">Vastgezette memo's</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Notitieboek maken</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
        <source>Search</source>
        <translation type="unfinished">Zoeken</translation>
    </message>
</context>
<context>
    <name>MoveDialog</name>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
        <source>Move Note</source>
        <translation>Notitie verplaatsen</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
        <source>Cancel</source>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>MultipleChoices</name>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
        <source>%1 note selected</source>
        <translation>%1 notitie geselecteerd</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
        <source>Move</source>
        <translation type="unfinished">Verplaatsen</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
        <source>Save Note</source>
        <translation>Notitie opslaan</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
        <source>Save Voice</source>
        <translation>Stem opslaan</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
        <source>Delete</source>
        <translation type="unfinished">Verwijderen</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="69"/>
        <source>Save as MP3</source>
        <translation>Opslaan als mp3-bestand</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="70"/>
        <source>Voice to Text</source>
        <translation>Spraak-naar-tekst</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="71"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="72"/>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="73"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="74"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="75"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="78"/>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="84"/>
        <source>Save as</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="93"/>
        <source>Text to Speech</source>
        <translation>Tekst naar spraak</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="94"/>
        <source>Stop reading</source>
        <translation>Stop met lezen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="95"/>
        <source>Speech to Text</source>
        <translation>Spraak naar tekst</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="47"/>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="48"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="49"/>
        <source>New note</source>
        <translation type="unfinished">Nieuwe memo</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="63"/>
        <source>Save as HTML</source>
        <translation>Opslaan als html-bestand</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="64"/>
        <source>Save as TXT</source>
        <translation>Opslaan als tekstbestand</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="57"/>
        <source>Save note</source>
        <translation>Memo opslaan</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="52"/>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="54"/>
        <source>Move</source>
        <translation>Verplaatsen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="55"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="58"/>
        <source>Save voice recording</source>
        <translation>Memo opslaan</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="60"/>
        <source>New note</source>
        <translation>Nieuwe memo</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="53"/>
        <source>Sticky on Top</source>
        <translation>Vastzetten aan bovenkant</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
        <source>Please install 'UOS AI' from the App Store before using</source>
        <translation>Installeer 'UOS AI' van de App Store voordat u het gebruikt</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
        <source>No audio input device detected. Please check and try again</source>
        <translation>Geen audio-invoerapparaat gedetecteerd. Controleer en probeer opnieuw</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
        <source>No audio output device detected. Please check and try again</source>
        <translation>Geen audio-uitvoerapparaat gedetecteerd. Controleer en probeer opnieuw</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>deepin-voice-note</source>
        <translation>deepin-voice-note</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="../src/common/setting.cpp" line="24"/>
        <source>Basic</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="25"/>
        <source>Audio Source</source>
        <translation>Audiobron</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="26"/>
        <source>Internal</source>
        <translation>Intern</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="27"/>
        <source>Microphone</source>
        <translation>Microfoon</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="27"/>
        <source>Basic</source>
        <translation type="unfinished">Algemeen</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="32"/>
        <source>Audio Source</source>
        <translation type="unfinished">Audiobron</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="59"/>
        <source>Internal</source>
        <translation type="unfinished">Intern</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="68"/>
        <source>Microphone</source>
        <translation type="unfinished">Microfoon</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
        <source>New notebook</source>
        <translation>Nieuw notitieboek</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
        <source>Rename notebook</source>
        <translation>Notitieboek hernoemen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
        <source>Delete notebook</source>
        <translation>Notitieboek verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
        <source>New note</source>
        <translation type="unfinished">Nieuwe memo</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
        <source>Rename note</source>
        <translation>Notitie hernoemen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
        <source>Delete note</source>
        <translation>Notitie verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
        <source>Play/Pause</source>
        <translation>Afspelen/Pauzeren</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
        <source>Record voice</source>
        <translation>Stem opnemen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
        <source>Save note</source>
        <translation type="unfinished">Memo opslaan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
        <source>Save recordings</source>
        <translation>Opnames opslaan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
        <source>Copy</source>
        <translation type="unfinished">Kopiëren</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
        <source>Cut</source>
        <translation type="unfinished">Knippen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
        <source>Paste</source>
        <translation type="unfinished">Plakken</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
        <source>Redo</source>
        <translation>Opnieuw uitvoeren</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
        <source>Delete</source>
        <translation type="unfinished">Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen weergeven</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
        <source>Notebooks</source>
        <translation>Notaarboeken</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
        <source>Notes</source>
        <translation>Notities</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
        <source>Settings</source>
        <translation type="unfinished">Instellingen</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="16"/>
        <source>Settings</source>
        <translation type="unfinished">Instellingen</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
        <source>Privacy Policy</source>
        <translation>Privacybeleid</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>Voice Notes is een lichtgewicht memo-tool om tekstnotities en geluidsopnames te maken.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
        <source>Voice Note</source>
        <translation>Voice Note</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="../src/importolddata/upgradeview.cpp" line="35"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>Bezig met importeren van aantekeningen uit oude versie…</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="46"/>
        <source>1 min ago</source>
        <translation>1 min geleden</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="48"/>
        <source>%1 mins ago</source>
        <translation>%1 min geleden</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="56"/>
        <source>Yesterday</source>
        <translation>Gisteren</translation>
    </message>
    <message>
        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
        <source>2 mins ago</source>
        <translation>2 minuten geleden</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>Weet u zeker dat u dit notebook wilt verwijderen?
Alle notities in het notebook worden verwijderd</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Wil je de huidige opname afbreken?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Deze memo kan niet worden omgezet omdat memo's van 20 minuten of langer momenteel niet worden ondersteund.</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">De memo wordt momenteel omgezet. Wil je dit proces afbreken?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Het invoervolume is laag, wat kan leiden tot slechte opnames. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">De geknipte memo's en omgezette tekst worden niet geplakt. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Weet je zeker dat je deze memo wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Weet je zeker dat je de %1 geselecteerde aantekeningen wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished">Ja</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
        <source>Save failed</source>
        <translation type="unfinished">Opslaan mislukt</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">Je bent niet bevoegd om hier bestanden op te slaan</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">De memo is verwijderd</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogHandler</name>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
        <source>Are you sure you want to delete this notebook?</source>
        <translation>Weet u zeker dat u dit notebook wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Wil je de huidige opname afbreken?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="103"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Weet je zeker dat je de %1 geselecteerde aantekeningen wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="107"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Weet je zeker dat je deze memo wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="110"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Deze memo kan niet worden omgezet omdat memo's van 20 minuten of langer momenteel niet worden ondersteund.</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="114"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">De memo wordt momenteel omgezet. Wil je dit proces afbreken?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="116"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Het invoervolume is laag, wat kan leiden tot slechte opnames. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="119"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">De geknipte memo's en omgezette tekst worden niet geplakt. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="123"/>
        <source>Save failed</source>
        <translation type="unfinished">Opslaan mislukt</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="125"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">Je bent niet bevoegd om hier bestanden op te slaan</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="127"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">De memo is verwijderd</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>De spraakomzetting is mislukt vanwege de slechte netwerkverbinding, controleer aub</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
        <source>All notes in it will be deleted</source>
        <translation>Alle notities in het notebook worden verwijderd</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
        <source>Delete</source>
        <translation type="unfinished">Verwijderen</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogLoader</name>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="150"/>
        <source>Cancel</source>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="183"/>
        <source>Confirm</source>
        <translation type="unfinished">Ja</translation>
    </message>
</context>
<context>
    <name>WebEngineHandler</name>
    <message>
        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
        <source>save as MP3</source>
        <translation>Opslaan als MP3</translation>
    </message>
</context>
<context>
    <name>WindowTitleBar</name>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
        <source>Create Note</source>
        <translation>Notitie maken</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>Start recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>No recording device detected</source>
        <translation>Geen opnamedevice gedetecteerd</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
        <source>Insert picture</source>
        <translation>Afbeelding invoegen</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="../src/common/jscontent.cpp" line="146"/>
        <source>Font</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="147"/>
        <source>Font size</source>
        <translation>Tekstgrootte</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="148"/>
        <source>Font color</source>
        <translation>Tekstkleur</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="149"/>
        <source>Text highlight color</source>
        <translation>Markeerkleur</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="150"/>
        <source>Bold</source>
        <translation>Vetgedrukt</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="151"/>
        <source>Italic</source>
        <translation>Cunsief</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="152"/>
        <source>Underline</source>
        <translation>Onderstrepen</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="153"/>
        <source>Strikethrough</source>
        <translation>Doorhalen</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="154"/>
        <source>Bullets</source>
        <translation>Ongenummerde lijst</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="155"/>
        <source>Numbering</source>
        <translation>Genummerde lijst</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="156"/>
        <source>More colors</source>
        <translation>Meer kleuren</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="157"/>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="173"/>
        <source>Voice To Text</source>
        <translation>Spraak naar tekst</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="174"/>
        <source>Converting voice to text</source>
        <translation>Spraak naar tekst converteren</translation>
    </message>
</context>
</TS>
